summary refs log tree commit diff
path: root/pkgs/tools/networking/openssh/default.nix
diff options
context:
space:
mode:
authorBen Siraphob <bensiraphob@gmail.com>2021-01-17 10:51:22 +0700
committerJonathan Ringer <jonringer@users.noreply.github.com>2021-01-16 23:49:59 -0800
commit76f93cc7313a1c32f7d76cf07c154e7bcafe251c (patch)
tree5582d94717ada25917f084cdd550ec900e90e82c /pkgs/tools/networking/openssh/default.nix
parentfce00d15c2521710ac1043d6b5251803fb9a8808 (diff)
pkgs/tools: pkgconfig -> pkg-config
Diffstat (limited to 'pkgs/tools/networking/openssh/default.nix')
-rw-r--r--pkgs/tools/networking/openssh/default.nix6
1 files changed, 3 insertions, 3 deletions
diff --git a/pkgs/tools/networking/openssh/default.nix b/pkgs/tools/networking/openssh/default.nix
index 18c185ffccedd..17a227c496aee 100644
--- a/pkgs/tools/networking/openssh/default.nix
+++ b/pkgs/tools/networking/openssh/default.nix
@@ -5,7 +5,7 @@
 , zlib
 , openssl
 , libedit
-, pkgconfig
+, pkg-config
 , pam
 , autoreconfHook
 , etcDir ? null
@@ -67,7 +67,7 @@ stdenv.mkDerivation rec {
       substituteInPlace Makefile.in --replace '$(INSTALL) -m 4711' '$(INSTALL) -m 0711'
     '';
 
-  nativeBuildInputs = [ pkgconfig ]
+  nativeBuildInputs = [ pkg-config ]
     ++ optional (hpnSupport || withGssapiPatches) autoreconfHook
     ++ optional withKerberos pkgs.kerberos.dev;
   buildInputs = [ zlib openssl libedit pam ]
@@ -82,7 +82,7 @@ stdenv.mkDerivation rec {
   # Upstream build system does not support static build, so we fall back
   # on fragile patching of configure script.
   #
   # libedit is found by pkgconfig, but without --static flag, required
   # to get also transitive dependencies for static linkage, hence sed
   # expression.
   #
@@ -82,7 +82,7 @@ stdenv.mkDerivation rec {
   # on fragile patching of configure script.
   #
-  # libedit is found by pkgconfig, but without --static flag, required
+  # libedit is found by pkg-config, but without --static flag, required
   # to get also transitive dependencies for static linkage, hence sed
   # expression.